@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2011 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2013 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -82,12 +82,46 @@ public class Questions {
 
     public static final String AVERAGE_NUMBER_OF_CONTACTS_PER_USER_WHO_HAS_CONTACTS_AT_ALL = "averageNumberOfContactsPerUserWhoHasContactsAtAll";
 
+    public static final String AVERAGE_NUMBER_OF_CONTACTS_PER_USER_WHO_HAS_CREATED_CONTACTS = "averageNumberOfContactsPerUserWhoHasCreatedContacts";
+
+    public static final String AVERAGE_NUMBER_OF_APPOINTMENTS_PER_USER_WHO_HAS_APPOINTMENTS_AT_ALL = "averageNumberOfAppointmentsPerUserWhoHasAppointmentsAtAll";
+
+    public static final String AVERAGE_NUMBER_OF_TASKS_PER_USER_WHO_HAS_TASKS_AT_ALL = "averageNumberOfTasksPerUserWhoHasTasksAtAll";
+
+    public static final String AVERAGE_NUMBER_OF_DOCUMENTS_PER_USER_WHO_HAS_DOCUMENTS_AT_ALL = "averageNumberOfDocumentsPerUserWhoHasDocumentsAtAll";
+
     public static final String NUMBER_OF_USERS_WHO_CHANGED_THEIR_CONTACTS_IN_THE_LAST30_DAYS = "numberOfUsersWhoChangedTheirContactsInTheLast30Days";
 
+    public static final String NUMBER_OF_USERS_WHO_HAVE_CONTACTS = "numberOfUsersWhoHaveContacts";
+
     public static final String NUMBER_OF_USERS_WHO_CREATED_CONTACTS = "numberOfUsersWhoCreatedContacts";
 
+    public static final String MAXIMUM_NUMBER_OF_CONTACTS_FOR_ONE_USER = "maximumNumberOfContactsForOneUser";
+
+    public static final String MAXIMUM_NUMBER_OF_CREATED_CONTACTS_FOR_ONE_USER = "maximumNumberOfCreatedContactsForOneUser";
+
+    public static final String MAXIMUM_NUMBER_OF_CREATED_APPOINTMENTS_FOR_ONE_USER = "maximumNumberOfCreatedAppointmentsForOneUser";
+
+    public static final String MAXIMUM_NUMBER_OF_CREATED_DOCUMENTS_FOR_ONE_USER = "maximumNumberOfCreatedDocumentsForOneUser";
+
+    public static final String MAXIMUM_NUMBER_OF_CREATED_TASKS_FOR_ONE_USER = "maximumNumberOfCreatedTasksForOneUser";
+
     public static final String NUMBER_OF_CONTACTS = "numberOfContacts";
 
+    public static final String NUMBER_OF_USER_CREATED_CONTACTS = "numberOfUSerCreatedContacts";
+
+    public static final String NUMBER_OF_USERS_WHO_CREATED_APPOINTMENTS = "numberOfUsersWhoCreatedAppointments";
+
+    public static final String NUMBER_OF_APPOINTMENTS = "numberOfAppointments";
+
+    public static final String NUMBER_OF_USERS_WHO_CREATED_TASKS = "numberOfUsersWhoCreatedTasks";
+
+    public static final String NUMBER_OF_TASKS = "numberOfTasks";
+
+    public static final String NUMBER_OF_USERS_WHO_CREATED_DOCUMENTS = "numberOfUsersWhoCreatedDocuments";
+
+    public static final String NUMBER_OF_DOCUMENTS = "numberOfDocuments";
+
     public static final String NUMBER_OF_USERS_WITH_NEW_INFOSTORE_OBJECTS_IN_THE_LAST30_DAYS = "numberOfUsersWithNewInfostoreObjectsInTheLast30Days";
 
     public static final String NUMBER_OF_CHANGED_INFOSTORE_OBJECTS_IN_THE_LAST30_DAYS = "numberOfChangedInfostoreObjectsInTheLast30Days";
@@ -128,6 +162,22 @@ public class Questions {
 
     public static final String NUMBER_OF_USERS_WHO_CHANGED_THEIR_TASKS_IN_THE_LAST30_DAYS = "numberOfUsersWhoChangedTheirTasksInTheLast30Days";
 
+    public static final String NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_OX6UI_IN_THE_LAST_30_DAYS = "numberOfUsersWhoLoggedInWithClientOX6UIInTheLast30Days";
+
+    public static final String NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_APPSUITEUI_IN_THE_LAST_30_DAYS = "numberOfUsersWhoLoggedInWithClientAppSuiteUIInTheLast30Days";
+
+    public static final String NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_EAS_IN_THE_LAST_30_DAYS = "numberOfUsersWhoUsedEASInTheLast30Days";
+
+    public static final String NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_MOBILEUI_IN_THE_LAST_30_DAYS = "numberOfUsersWhoLoggedInWithClientMobileUIInTheLast30Days";
+
+    public static final String NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_CALDAV_IN_THE_LAST_30_DAYS = "numberOfUsersWhoUsedCalDAVInTheLast30Days";
+
+    public static final String NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_CARDDAV_IN_THE_LAST_30_DAYS = "numberOfUsersWhoUsedCardDAVInTheLast30Days";
+
+    public static final String AVERAGE_DOCUMENT_SIZE = "averageDocumentSize";
+
+
+
     protected static void reportNumberOfUsers() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS);
@@ -170,16 +220,6 @@ public class Questions {
         }
     }
 
-    protected static void reportNumberOfInfostoreObjects() {
-        try {
-            Datamining.allTheQuestions.add(NUMBER_OF_INFOSTORE_OBJECTS);
-            String sql = "SELECT COUNT(*) FROM infostore";
-            BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
-            Datamining.report(NUMBER_OF_INFOSTORE_OBJECTS, numberOfInfostoreObjects.toString());
-        } catch (Exception e) {
-        }
-    }
-
     protected static void reportNumberOfNewInfostoreObjectsInTheLast30Days() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_NEW_INFOSTORE_OBJECTS_IN_THE_LAST30_DAYS);
@@ -214,8 +254,58 @@ public class Questions {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_CONTACTS);
             String sql = "SELECT count(*) FROM prg_contacts WHERE userid IS NULL;";
+            BigInteger numberOfContacts = Datamining.countOverAllSchemata(sql);
+            Datamining.report(NUMBER_OF_CONTACTS, numberOfContacts.toString());
+        } catch (Exception e) {
+        }
+    }
+
+    protected static void reportNumberOfUserCreatedContacts() {
+        try {
+            Datamining.allTheQuestions.add(NUMBER_OF_USER_CREATED_CONTACTS);
+            String sql = "SELECT count(*) FROM prg_contacts WHERE userid IS NULL AND field02 IS NOT NULL AND field03 IS NOT NULL;";
+            BigInteger numberOfContacts = Datamining.countOverAllSchemata(sql);
+            Datamining.report(NUMBER_OF_USER_CREATED_CONTACTS, numberOfContacts.toString());
+        } catch (Exception e) {
+        }
+    }
+
+    protected static void reportNumberOfAppointments() {
+        try {
+            Datamining.allTheQuestions.add(NUMBER_OF_APPOINTMENTS);
+            String sql = "SELECT count(*) FROM prg_dates;";
+            BigInteger numberOfAppointments = Datamining.countOverAllSchemata(sql);
+            Datamining.report(NUMBER_OF_APPOINTMENTS, numberOfAppointments.toString());
+        } catch (Exception e) {
+        }
+    }
+
+    protected static void reportNumberOfTasks() {
+        try {
+            Datamining.allTheQuestions.add(NUMBER_OF_TASKS);
+            String sql = "SELECT count(*) FROM task;";
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
-            Datamining.report(NUMBER_OF_CONTACTS, numberOfInfostoreObjects.toString());
+            Datamining.report(NUMBER_OF_TASKS, numberOfInfostoreObjects.toString());
+        } catch (Exception e) {
+        }
+    }
+
+    protected static void reportNumberOfDocuments() {
+        try {
+            Datamining.allTheQuestions.add(NUMBER_OF_DOCUMENTS);
+            String sql = "SELECT count(*) FROM infostore_document;";
+            BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
+            Datamining.report(NUMBER_OF_DOCUMENTS, numberOfInfostoreObjects.toString());
+        } catch (Exception e) {
+        }
+    }
+
+    protected static void reportNumberOfUsersWhoHaveContacts() {
+        try {
+            Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_HAVE_CONTACTS);
+            String sql = "SELECT count(DISTINCT created_from, cid) FROM prg_contacts WHERE userid IS NULL;";
+            BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
+            Datamining.report(NUMBER_OF_USERS_WHO_HAVE_CONTACTS, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
         }
     }
@@ -223,17 +313,97 @@ public class Questions {
     protected static void reportNumberOfUsersWhoCreatedContacts() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_CREATED_CONTACTS);
-            String sql = "SELECT count(DISTINCT created_from, cid) FROM prg_contacts WHERE userid IS NULL;";
+            String sql = "SELECT count(DISTINCT created_from, cid) FROM prg_contacts WHERE userid IS NULL AND field02 IS NOT NULL AND field03 IS NOT NULL;";
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_CREATED_CONTACTS, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
         }
     }
 
+    protected static void reportMaximumNumberOfContactsForOneUser() {
+        try {
+            Datamining.allTheQuestions.add(MAXIMUM_NUMBER_OF_CREATED_CONTACTS_FOR_ONE_USER);
+            String sql = "SELECT MAX(count) FROM (SELECT cid, created_from, count(*) AS count FROM prg_contacts WHERE userid IS NULL GROUP BY cid, created_from) AS x;";
+            BigInteger numberOfInfostoreObjects = Datamining.maximumForAllSchemata(sql);
+            Datamining.report(MAXIMUM_NUMBER_OF_CREATED_CONTACTS_FOR_ONE_USER, numberOfInfostoreObjects.toString());
+        } catch (Exception e) {
+        }
+    }
+
+    protected static void reportMaximumNumberOfCreatedAppointmentsForOneUser() {
+        try {
+            Datamining.allTheQuestions.add(MAXIMUM_NUMBER_OF_CREATED_APPOINTMENTS_FOR_ONE_USER);
+            String sql = "SELECT MAX(count) FROM (SELECT cid, created_from, count(*) AS count FROM prg_dates) AS x;";
+            BigInteger numberOfInfostoreObjects = Datamining.maximumForAllSchemata(sql);
+            Datamining.report(MAXIMUM_NUMBER_OF_CREATED_APPOINTMENTS_FOR_ONE_USER, numberOfInfostoreObjects.toString());
+        } catch (Exception e) {
+        }
+    }
+
+    protected static void reportMaximumNumberOfCreatedDocumentsForOneUser() {
+        try {
+            Datamining.allTheQuestions.add(MAXIMUM_NUMBER_OF_CREATED_DOCUMENTS_FOR_ONE_USER);
+            String sql = "SELECT MAX(count) FROM (SELECT cid, created_by, count(*) AS count FROM infostore_document) AS x;";
+            BigInteger numberOfInfostoreObjects = Datamining.maximumForAllSchemata(sql);
+            Datamining.report(MAXIMUM_NUMBER_OF_CREATED_DOCUMENTS_FOR_ONE_USER, numberOfInfostoreObjects.toString());
+        } catch (Exception e) {
+        }
+    }
+
+    protected static void reportMaximumNumberOfCreatedTasksForOneUser() {
+        try {
+            Datamining.allTheQuestions.add(MAXIMUM_NUMBER_OF_CREATED_TASKS_FOR_ONE_USER);
+            String sql = "SELECT MAX(count) FROM (SELECT cid, created_from, count(*) AS count FROM task) AS x;";
+            BigInteger numberOfInfostoreObjects = Datamining.maximumForAllSchemata(sql);
+            Datamining.report(MAXIMUM_NUMBER_OF_CREATED_TASKS_FOR_ONE_USER, numberOfInfostoreObjects.toString());
+        } catch (Exception e) {
+        }
+    }
+
+    protected static void reportMaximumNumberOfCreatedContactsForOneUser() {
+        try {
+            Datamining.allTheQuestions.add(MAXIMUM_NUMBER_OF_CREATED_CONTACTS_FOR_ONE_USER);
+            String sql = "SELECT MAX(count) FROM (SELECT cid, created_from, count(*) AS count FROM prg_contacts WHERE userid IS NULL AND field02 IS NOT NULL AND field03 IS NOT NULL GROUP BY cid, created_from) AS x;";
+            BigInteger numberOfInfostoreObjects = Datamining.maximumForAllSchemata(sql);
+            Datamining.report(MAXIMUM_NUMBER_OF_CREATED_CONTACTS_FOR_ONE_USER, numberOfInfostoreObjects.toString());
+        } catch (Exception e) {
+        }
+    }
+
+    protected static void reportNumberOfUsersWhoCreatedAppointments() {
+        try {
+            Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_CREATED_APPOINTMENTS);
+            String sql = "SELECT count(DISTINCT created_from, cid) FROM prg_dates;";
+            BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
+            Datamining.report(NUMBER_OF_USERS_WHO_CREATED_APPOINTMENTS, numberOfInfostoreObjects.toString());
+        } catch (Exception e) {
+        }
+    }
+
+    protected static void reportNumberOfUsersWhoCreatedTasks() {
+        try {
+            Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_CREATED_TASKS);
+            String sql = "SELECT count(DISTINCT created_from, cid) FROM task;";
+            BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
+            Datamining.report(NUMBER_OF_USERS_WHO_CREATED_TASKS, numberOfInfostoreObjects.toString());
+        } catch (Exception e) {
+        }
+    }
+
+    protected static void reportNumberOfUsersWhoCreatedDocuments() {
+        try {
+            Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_CREATED_DOCUMENTS);
+            String sql = "SELECT count(DISTINCT created_by, cid) FROM infostore_document;";
+            BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
+            Datamining.report(NUMBER_OF_USERS_WHO_CREATED_DOCUMENTS, numberOfInfostoreObjects.toString());
+        } catch (Exception e) {
+        }
+    }
+
     protected static void reportNumberOfUsersWhoChangedTheirContactsInTheLast30Days() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_CHANGED_THEIR_CONTACTS_IN_THE_LAST30_DAYS);
-            String sql = "SELECT count(DISTINCT created_from, cid) FROM prg_contacts WHERE userid IS NULL AND (DATE(FROM_UNIXTIME(SUBSTRING(CAST(changing_date AS CHAR) FROM 1 FOR 10))) BETWEEN (NOW() - INTERVAL 30 DAY) AND NOW());";
+            String sql = "SELECT count(DISTINCT created_from, cid) FROM prg_contacts WHERE userid IS NULL AND field02 IS NOT NULL AND field03 IS NOT NULL AND (DATE(FROM_UNIXTIME(SUBSTRING(CAST(changing_date AS CHAR) FROM 1 FOR 10))) BETWEEN (NOW() - INTERVAL 30 DAY) AND NOW());";
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_CHANGED_THEIR_CONTACTS_IN_THE_LAST30_DAYS, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
@@ -265,6 +435,19 @@ public class Questions {
         }
     }
 
+    protected static void reportAverageDocumentSize() {
+    	try {
+            Datamining.allTheQuestions.add(AVERAGE_DOCUMENT_SIZE);
+
+            String sql = "SELECT AVG(file_size) FROM infostore_document;";
+            Float result = Datamining.averageForAllSchemata(sql);
+            int resultInt = Math.round(result);
+
+            Datamining.report(AVERAGE_DOCUMENT_SIZE, Tools.humanReadableBytes(Integer.toString(resultInt)));
+        } catch (Exception e) {
+        }
+    }
+
     public static void reportAverageNumberOfContactsPerUserWhoHasContactsAtAll() {
         try {
             Datamining.allTheQuestions.add(AVERAGE_NUMBER_OF_CONTACTS_PER_USER_WHO_HAS_CONTACTS_AT_ALL);
@@ -273,7 +456,7 @@ public class Questions {
             // divide the two (numberOfContacts / (numberOfUsers - numberOfContexts)) -> average number of contacts per User
 
             float numberOfContacts = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_CONTACTS));
-            float numberOfUsers = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_USERS_WHO_CREATED_CONTACTS));
+            float numberOfUsers = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_USERS_WHO_HAVE_CONTACTS));
 
             Datamining.report(
                 AVERAGE_NUMBER_OF_CONTACTS_PER_USER_WHO_HAS_CONTACTS_AT_ALL,
@@ -282,6 +465,65 @@ public class Questions {
         }
     }
 
+    public static void reportAverageNumberOfContactsPerUserWhoHasCreatedContacts() {
+        try {
+            Datamining.allTheQuestions.add(AVERAGE_NUMBER_OF_CONTACTS_PER_USER_WHO_HAS_CREATED_CONTACTS);
+            // take numberOfContacts
+            // take numberOfUsers and subtract numberOfContexts (thereby not counting the context-admins) -> relevant number of users
+            // divide the two (numberOfContacts / (numberOfUsers - numberOfContexts)) -> average number of contacts per User
+
+            float numberOfContacts = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_USER_CREATED_CONTACTS));
+            float numberOfUsers = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_USERS_WHO_CREATED_CONTACTS));
+
+            Datamining.report(
+                AVERAGE_NUMBER_OF_CONTACTS_PER_USER_WHO_HAS_CREATED_CONTACTS,
+                Float.toString(numberOfContacts / numberOfUsers));
+        } catch (Exception e) {
+        }
+    }
+
+    public static void reportAverageNumberOfAppointmentsPerUserWhoHasAppointmentsAtAll() {
+        try {
+            Datamining.allTheQuestions.add(AVERAGE_NUMBER_OF_APPOINTMENTS_PER_USER_WHO_HAS_APPOINTMENTS_AT_ALL);
+
+            float numberOfAppointments = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_APPOINTMENTS));
+            float numberOfUsers = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_USERS_WHO_CREATED_APPOINTMENTS));
+
+            Datamining.report(
+                AVERAGE_NUMBER_OF_APPOINTMENTS_PER_USER_WHO_HAS_APPOINTMENTS_AT_ALL,
+                Float.toString(numberOfAppointments / numberOfUsers));
+        } catch (Exception e) {
+        }
+    }
+
+    public static void reportAverageNumberOfTasksPerUserWhoHasTasksAtAll() {
+        try {
+            Datamining.allTheQuestions.add(AVERAGE_NUMBER_OF_TASKS_PER_USER_WHO_HAS_TASKS_AT_ALL);
+
+            float numberOfTasks = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_TASKS));
+            float numberOfUsers = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_USERS_WHO_CREATED_TASKS));
+
+            Datamining.report(
+                AVERAGE_NUMBER_OF_TASKS_PER_USER_WHO_HAS_TASKS_AT_ALL,
+                Float.toString(numberOfTasks / numberOfUsers));
+        } catch (Exception e) {
+        }
+    }
+
+    public static void reportAverageNumberOfDocumentsPerUserWhoHasDocumentsAtAll() {
+        try {
+            Datamining.allTheQuestions.add(AVERAGE_NUMBER_OF_DOCUMENTS_PER_USER_WHO_HAS_DOCUMENTS_AT_ALL);
+
+            float numberOfDocuments = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_DOCUMENTS));
+            float numberOfUsers = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_USERS_WHO_CREATED_DOCUMENTS));
+
+            Datamining.report(
+                AVERAGE_NUMBER_OF_DOCUMENTS_PER_USER_WHO_HAS_DOCUMENTS_AT_ALL,
+                Float.toString(numberOfDocuments / numberOfUsers));
+        } catch (Exception e) {
+        }
+    }
+
     public static void reportNumberOfUsersWithLinkedSocialNetworkingAccounts() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_WITH_LINKED_SOCIAL_NETWORKING_ACCOUNTS);
@@ -521,4 +763,64 @@ public class Questions {
         } catch (Exception e) {
         }
     }
+
+    protected static void reportNumberOfUsersWhoLoggedInWithClientOX6UIInTheLast30Days() {
+        try {
+            Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_OX6UI_IN_THE_LAST_30_DAYS);
+            String sql = "SELECT count(DISTINCT id, cid) FROM user_attribute WHERE name = 'client:com.openexchange.ox.gui.dhtml' AND DATE(FROM_UNIXTIME(SUBSTRING(CAST(value AS CHAR) FROM 1 FOR 10))) BETWEEN (NOW() - INTERVAL 30 DAY) AND NOW()";
+            BigInteger numberOfUsers = Datamining.countOverAllSchemata(sql);
+            Datamining.report(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_OX6UI_IN_THE_LAST_30_DAYS, numberOfUsers.toString());
+        } catch (Exception e) {
+        }
+    }
+
+    protected static void reportNumberOfUsersWhoLoggedInWithClientAppSuiteUIInTheLast30Days() {
+        try {
+            Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_APPSUITEUI_IN_THE_LAST_30_DAYS);
+            String sql = "SELECT count(DISTINCT id, cid) FROM user_attribute WHERE name = 'client:open-xchange-appsuite' AND DATE(FROM_UNIXTIME(SUBSTRING(CAST(value AS CHAR) FROM 1 FOR 10))) BETWEEN (NOW() - INTERVAL 30 DAY) AND NOW()";
+            BigInteger numberOfUsers = Datamining.countOverAllSchemata(sql);
+            Datamining.report(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_APPSUITEUI_IN_THE_LAST_30_DAYS, numberOfUsers.toString());
+        } catch (Exception e) {
+        }
+    }
+
+    protected static void reportNumberOfUsersWhoLoggedInWithClientEASInTheLast30Days() {
+        try {
+            Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_EAS_IN_THE_LAST_30_DAYS);
+            String sql = "SELECT count(DISTINCT id, cid) FROM user_attribute WHERE name = 'client:USM-EAS' AND DATE(FROM_UNIXTIME(SUBSTRING(CAST(value AS CHAR) FROM 1 FOR 10))) BETWEEN (NOW() - INTERVAL 30 DAY) AND NOW()";
+            BigInteger numberOfUsers = Datamining.countOverAllSchemata(sql);
+            Datamining.report(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_EAS_IN_THE_LAST_30_DAYS, numberOfUsers.toString());
+        } catch (Exception e) {
+        }
+    }
+
+    protected static void reportNumberOfUsersWhoLoggedInWithClientMobileUIInTheLast30Days() {
+        try {
+            Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_MOBILEUI_IN_THE_LAST_30_DAYS);
+            String sql = "SELECT count(DISTINCT id, cid) FROM user_attribute WHERE name = 'client:com.openexchange.mobileapp' AND DATE(FROM_UNIXTIME(SUBSTRING(CAST(value AS CHAR) FROM 1 FOR 10))) BETWEEN (NOW() - INTERVAL 30 DAY) AND NOW()";
+            BigInteger numberOfUsers = Datamining.countOverAllSchemata(sql);
+            Datamining.report(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_MOBILEUI_IN_THE_LAST_30_DAYS, numberOfUsers.toString());
+        } catch (Exception e) {
+        }
+    }
+
+    protected static void reportNumberOfUsersWhoLoggedInWithClientCalDAVInTheLast30Days() {
+        try {
+            Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_CALDAV_IN_THE_LAST_30_DAYS);
+            String sql = "SELECT count(DISTINCT id, cid) FROM user_attribute WHERE name = 'client:CALDAV' AND DATE(FROM_UNIXTIME(SUBSTRING(CAST(value AS CHAR) FROM 1 FOR 10))) BETWEEN (NOW() - INTERVAL 30 DAY) AND NOW()";
+            BigInteger numberOfUsers = Datamining.countOverAllSchemata(sql);
+            Datamining.report(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_CALDAV_IN_THE_LAST_30_DAYS, numberOfUsers.toString());
+        } catch (Exception e) {
+        }
+    }
+
+    protected static void reportNumberOfUsersWhoLoggedInWithClientCardDAVInTheLast30Days() {
+        try {
+            Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_CARDDAV_IN_THE_LAST_30_DAYS);
+            String sql = "SELECT count(DISTINCT id, cid) FROM user_attribute WHERE name = 'client:CARDDAV' AND DATE(FROM_UNIXTIME(SUBSTRING(CAST(value AS CHAR) FROM 1 FOR 10))) BETWEEN (NOW() - INTERVAL 30 DAY) AND NOW()";
+            BigInteger numberOfUsers = Datamining.countOverAllSchemata(sql);
+            Datamining.report(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_CARDDAV_IN_THE_LAST_30_DAYS, numberOfUsers.toString());
+        } catch (Exception e) {
+        }
+    }
 }
